
From: Andrey Panin <pazke@donpac.ru>

This patch ports powernow-k7 driver to new DMI probing API.

Signed-off-by: Andrey Panin <pazke@donpac.ru>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k7.c |   28 ++++++++++++++++++++-
 25-akpm/arch/i386/kernel/dmi_scan.c                |   20 ---------------
 2 files changed, 27 insertions(+), 21 deletions(-)

diff -puN arch/i386/kernel/cpu/cpufreq/powernow-k7.c~267-mm1-port-powernow-k7-driver-to-new-dmi-probing arch/i386/kernel/cpu/cpufreq/powernow-k7.c
--- 25/arch/i386/kernel/cpu/cpufreq/powernow-k7.c~267-mm1-port-powernow-k7-driver-to-new-dmi-probing	Wed Jun 23 14:18:25 2004
+++ 25-akpm/arch/i386/kernel/cpu/cpufreq/powernow-k7.c	Wed Jun 23 14:18:25 2004
@@ -22,6 +22,7 @@
 #include <linux/cpufreq.h>
 #include <linux/slab.h>
 #include <linux/string.h>
+#include <linux/dmi.h>
 
 #include <asm/msr.h>
 #include <asm/timex.h>
@@ -554,6 +555,31 @@ static unsigned int powernow_get(unsigne
 }
 
 
+static int __init acer_cpufreq_pst(struct dmi_system_id *d)
+{
+	printk(KERN_WARNING "%s laptop with broken PST tables in BIOS detected.\n", d->ident);
+	printk(KERN_WARNING "You need to downgrade to 3A21 (09/09/2002), or try a newer BIOS than 3A71 (01/20/2003)\n");
+	printk(KERN_WARNING "cpufreq scaling has been disabled as a result of this.\n");
+	return 0;
+}
+
+/*
+ * Some Athlon laptops have really fucked PST tables.
+ * A BIOS update is all that can save them.
+ * Mention this, and disable cpufreq.
+ */
+static struct dmi_system_id __initdata powernow_dmi_table[] = {
+	{
+		.callback = acer_cpufreq_pst,
+		.ident = "Acer Aspire",
+		.matches = {
+			DMI_MATCH(DMI_SYS_VENDOR, "Insyde Software"),
+			DMI_MATCH(DMI_BIOS_VERSION, "3A71"),
+		},
+	},
+	{ }
+};
+
 static int __init powernow_cpu_init (struct cpufreq_policy *policy)
 {
 	union msr_fidvidstatus fidvidstatus;
@@ -572,7 +598,7 @@ static int __init powernow_cpu_init (str
 	}
 	dprintk(KERN_INFO PFX "FSB: %3d.%03d MHz\n", fsb/1000, fsb%1000);
 
-	if ((dmi_broken & BROKEN_CPUFREQ) || acpi_force) {
+ 	if (dmi_check_system(powernow_dmi_table) || acpi_force) {
 		printk (KERN_INFO PFX "PSB/PST known to be broken.  Trying ACPI instead\n");
 		result = powernow_acpi_init();
 	} else {
diff -puN arch/i386/kernel/dmi_scan.c~267-mm1-port-powernow-k7-driver-to-new-dmi-probing arch/i386/kernel/dmi_scan.c
--- 25/arch/i386/kernel/dmi_scan.c~267-mm1-port-powernow-k7-driver-to-new-dmi-probing	Wed Jun 23 14:18:25 2004
+++ 25-akpm/arch/i386/kernel/dmi_scan.c	Wed Jun 23 14:18:25 2004
@@ -400,15 +400,6 @@ static __init int broken_ps2_resume(stru
 	return 0;
 }
 
-static __init int acer_cpufreq_pst(struct dmi_blacklist *d)
-{
-	printk(KERN_WARNING "%s laptop with broken PST tables in BIOS detected.\n", d->ident);
-	printk(KERN_WARNING "You need to downgrade to 3A21 (09/09/2002), or try a newer BIOS than 3A71 (01/20/2003)\n");
-	printk(KERN_WARNING "cpufreq scaling has been disabled as a result of this.\n");
-	dmi_broken |= BROKEN_CPUFREQ;
-	return 0;
-}
-
 
 /*
  *	Simple "print if true" callback
@@ -761,17 +752,6 @@ static __initdata struct dmi_blacklist d
 			NO_MATCH, NO_MATCH, NO_MATCH
 			} },
 
-	/*
-	 * Some Athlon laptops have really fucked PST tables.
-	 * A BIOS update is all that can save them.
-	 * Mention this, and disable cpufreq.
-	 */
-	{ acer_cpufreq_pst, "Acer Aspire", {
-			MATCH(DMI_SYS_VENDOR, "Insyde Software"),
-			MATCH(DMI_BIOS_VERSION, "3A71"),
-			NO_MATCH, NO_MATCH,
-			} },
-
 	/*      
 	 * Several HP Proliant (and maybe other OSB4/ProFusion) systems
 	 * can't use i8042 in mux mode, or they crash or reboot.
_
